@@ -17,6 +17,18 @@
 
 ###  deal with the optimization level for c++ compilation 
 
+get_all_makefile_paths <- function() {
+  out <- system2(file.path(Sys.getenv("R_HOME"), "bin", "R"),
+                 args = "CMD SHLIB --dry-run", stdout = TRUE)
+  out <- grep("SHLIB", out, value = TRUE)[1]
+  makefiles <- strsplit(sub("SHLIB.*$", "", out), split = "-f ")[[1]][-1]
+  makefiles <- gsub("'", "", makefiles)
+  makefiles <- gsub("[[:space:]]*$", "", makefiles)
+  makefiles <- gsub('\"', '', makefiles)
+  makefiles <- makefiles[file.exists(makefiles)]
+  return(makefiles)  
+}
+
 get_makefile_txt <- function() { 
   # get the all makefile content used for R CMD SHLIB 
   # The order or files to look for are following the code 
@@ -25,13 +37,7 @@ get_makefile_txt <- function() {
   # Return: 
   #   a character vector in which each element is a line of 
   #   the makefile 
-  out <- system2(file.path(Sys.getenv("R_HOME"), "bin", "R"),
-                 args = "CMD SHLIB --dry-run", stdout = TRUE)[2]
-  makefiles <- strsplit(sub("SHLIB.*$", "", out), split = "-f ")[[1]][-1]
-  makefiles <- gsub("'", "", makefiles)
-  makefiles <- gsub("[[:space:]]*$", "", makefiles)
-  makefiles <- gsub('\"', '', makefiles)
-  makefiles <- makefiles[file.exists(makefiles)]
+  makefiles <- get_all_makefile_paths()
   do.call(c, lapply(makefiles, function(f) readLines(f, warn = FALSE))) 
 }
 
@@ -48,12 +54,13 @@ get_makefile_flags <- function(FLAGNAME, makefile_txt, headtotail = FALSE) {
 
   if (missing(makefile_txt)) 
     makefile_txt <- get_makefile_txt() 
+  if (length(makefile_txt) == 0) return(as.character(NULL))
 
   lineno <- -1 
   iseq <- if (headtotail) 1:length(makefile_txt) else length(makefile_txt):1 
   for (i in iseq) { 
     pattern <- paste("^\\s*", FLAGNAME, "\\s*=", sep = '')
-    if (grepl(pattern, makefile_txt[i])) {
+    if (!is.null(makefile_txt[i]) && grepl(pattern, makefile_txt[i])) {
       lineno <- i 
       break;
     }
@@ -70,23 +77,8 @@ last_makefile <- function() {
   # This function return the last one, where we can set flags 
   # to overwrite what is set before. 
   # 
-  WINDOWS <- .Platform$OS.type == "windows"
-  rarch <- Sys.getenv("R_ARCH") # unix only
-  if (WINDOWS && nzchar(.Platform$r_arch))
-    rarch <- paste0("/", .Platform$r_arch)
-
-  if (WINDOWS) { 
-    if (rarch == "/x64") {
-       f <- path.expand("~/.R/Makevars.win64") 
-       if (file.exists(f)) return(f) 
-    }
-    f <- path.expand("~/.R/Makevars.win") 
-    if (file.exists(f)) return(f) 
-    return(path.expand("~/.R/Makevars"))
-  }
-  f <- path.expand(paste("~/.R/Makevars", Sys.getenv("R_PLATFORM"), sep = "-"))
-  if (file.exists(f)) return(f) 
-  return(path.expand("~/.R/Makevars"))
+  makefiles <- get_all_makefile_paths()
+  return(tail(makefiles, n = 1L))
 } 
 
 set_makefile_flags <- function(flags) { 
