@@ -47,7 +47,9 @@ PKG_CPPFLAGS_env_fun <- function() {
          ' -I"', file.path(inc_path_fun("StanHeaders"), '" '),
          ' -I"', inc_path_fun("rstan"), '"', 
          ' -DEIGEN_NO_DEBUG ',
-         ' -DBOOST_DISABLE_ASSERTS',
+         ' -D_REENTRANT ',
+         ' -DBOOST_DISABLE_ASSERTS -DBOOST_PENDING_INTEGER_LOG2_HPP',
+         ' -include stan/math/prim/mat/fun/Eigen.hpp ',
          ifelse (.Platform$OS.type == "windows", ' -std=c++1y', ''),
          sep = '')
 }
