@@ -116,7 +116,7 @@ stan_model <- function(file,
   # check for compilers
   if (.Platform$OS.type != "windows") {
     CXX <- get_CXX()
-    if (nchar(CXX) == 0) {
+    if (!is.null(attr(CXX, "status")) || nchar(CXX) == 0) {
       WIKI <- "https://github.com/stan-dev/rstan/wiki/RStan-Getting-Started"
       warning(paste("C++ compiler not found on system. If absent, see\n", WIKI))
     }
@@ -127,14 +127,17 @@ stan_model <- function(file,
   model_cppname <- stanc_ret$model_cppname 
   model_name <- stanc_ret$model_name 
   model_code <- stanc_ret$model_code 
+  model_cppcode <- stanc_ret$cppcode
   inc <- paste("#define STAN__SERVICES__COMMAND_HPP",
                # include, stanc_ret$cppcode,
-               if(is.null(includes)) stanc_ret$cppcode else
-                 sub("(class[[:space:]]+[A-Za-z_][A-Za-z0-9_]*[[:space:]]*: public prob_grad \\{)",
-                     paste(includes, "\\1"), stanc_ret$cppcode),
+               "#include <boost/integer/integer_log2.hpp>\n",
                "#include <rstan/rstaninc.hpp>\n", 
+               if(is.null(includes)) model_cppcode else
+                 sub("(class[[:space:]]+[A-Za-z_][A-Za-z0-9_]*[[:space:]]*)",
+                     paste(includes, "\\1"), model_cppcode),
                get_Rcpp_module_def_code(model_cppname), 
-               sep = '')  
+               sep = '')
+
 
   if (verbose && interactive())
     cat("COMPILING THE C++ CODE FOR MODEL '", model_name, "' NOW.\n", sep = '')
@@ -153,10 +156,6 @@ stan_model <- function(file,
   if (!file.exists(rstan_options("eigen_lib")))
     stop("Eigen not found; call install.packages('RcppEigen')")
   
-  if (packageVersion("StanHeaders") > packageVersion("rstan"))
-    stop("StanHeaders version is ahead of rstan version; ",
-         "see https://github.com/stan-dev/rstan/wiki/RStan-Transition-Periods")
-    
 
   dso <- cxxfunctionplus(signature(), body = paste(" return Rcpp::wrap(\"", model_name, "\");", sep = ''), 
                          includes = inc, plugin = "rstan", save_dso = save_dso | auto_write,
@@ -183,7 +182,7 @@ stan_model <- function(file,
              dso = dso, # keep a reference to dso
              mk_cppmodule = mk_cppmodule,  # mk_cppmodule function is defined in file stanmodel-class.R
              model_cpp = list(model_cppname = model_cppname, 
-                              model_cppcode = stanc_ret$cppcode))
+                              model_cppcode = model_cppcode))
   
   if(missing(file) || (file.access(dirname(file), mode = 2) != 0) || !isTRUE(auto_write)) {
     tf <- tempfile()
