@@ -1,4 +1,4 @@
-## ----setup, include=FALSE------------------------------------------------
+## ----setup, include=FALSE-----------------------------------------------------
 library(rstan)
 knitr::opts_chunk$set(
   echo = TRUE,
@@ -8,21 +8,21 @@ knitr::opts_chunk$set(
   fig.width = 7
   )
 
-## ---- echo=FALSE, comment=""---------------------------------------------
+## ---- echo=FALSE, comment=""--------------------------------------------------
 cat(readLines("schools.stan"), sep = "\n")
 
-## ---- lookup-------------------------------------------------------------
+## ---- lookup------------------------------------------------------------------
 lookup("dnorm")
 lookup(dwilcox)   # no corresponding Stan function
 
-## ---- schools-data-------------------------------------------------------
+## ---- schools-data------------------------------------------------------------
 schools_data <- list(
   J = 8,
   y = c(28,  8, -3,  7, -1,  1, 18, 12),
   sigma = c(15, 10, 16, 11,  9, 11, 10, 18)
 )
 
-## ---- callstan, results="hide"-------------------------------------------
+## ---- callstan, results="hide"------------------------------------------------
 library(rstan)
 fit1 <- stan(
   file = "schools.stan",  # Stan program
@@ -30,23 +30,23 @@ fit1 <- stan(
   chains = 4,             # number of Markov chains
   warmup = 1000,          # number of warmup iterations per chain
   iter = 2000,            # total number of iterations per chain
-  cores = 2,              # number of cores (using 2 just for the vignette)
-  refresh = 1000          # show progress every 'refresh' iterations
+  cores = 2,              # number of cores (could use one per chain)
+  refresh = 0             # no progress shown
   )
 
-## ---- print--------------------------------------------------------------
+## ---- print-------------------------------------------------------------------
 print(fit1, pars=c("theta", "mu", "tau", "lp__"), probs=c(.1,.5,.9))
 
-## ---- stanfit-plot-------------------------------------------------------
+## ---- stanfit-plot------------------------------------------------------------
 plot(fit1)
 
-## ---- stanfit-traceplot--------------------------------------------------
+## ---- stanfit-traceplot-------------------------------------------------------
 traceplot(fit1, pars = c("mu", "tau"), inc_warmup = TRUE, nrow = 2)
 
-## ---- stanfit-print------------------------------------------------------
+## ---- stanfit-print-----------------------------------------------------------
 print(fit1, pars = c("mu", "tau"))
 
-## ---- get_sampler_params-------------------------------------------------
+## ---- get_sampler_params------------------------------------------------------
 # all chains combined
 sampler_params <- get_sampler_params(fit1, inc_warmup = TRUE)
 summary(do.call(rbind, sampler_params), digits = 2)
@@ -54,10 +54,10 @@ summary(do.call(rbind, sampler_params), digits = 2)
 # each chain separately
 lapply(sampler_params, summary, digits = 2)
 
-## ---- pairs-plot---------------------------------------------------------
+## ---- pairs-plot--------------------------------------------------------------
 pairs(fit1, pars = c("mu", "tau", "lp__"), las = 1)
 
-## ---- expose_stan_functions----------------------------------------------
+## ---- expose_stan_functions---------------------------------------------------
 model_code <-
 '
 functions {
@@ -68,9 +68,9 @@ functions {
 model {}
 '
 expose_stan_functions(stanc(model_code = model_code))
-standard_normal_rng(seed = 1)
+standard_normal_rng()
 
-## ---- optimizer, results="hide"------------------------------------------
+## ---- optimizer, results="hide"-----------------------------------------------
 ocode <- "
   data {
     int<lower=1> N;
@@ -87,7 +87,7 @@ ocode <- "
 sm <- stan_model(model_code = ocode)
 y2 <- rnorm(20)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 mean(y2)
 optimizing(sm, data = list(y = y2, N = length(y2)), hessian = TRUE)
 
